@@ -859,7 +859,6 @@ pgm_drawable_set_position (PgmDrawable *drawable,
   PgmError ret = PGM_ERROR_OK;
   gboolean reordered = FALSE;
   PgmDrawableClass *klass;
-  GstObject *canvas;
 
   g_return_val_if_fail (PGM_IS_DRAWABLE (drawable), PGM_ERROR_X);
 
@@ -880,8 +879,6 @@ pgm_drawable_set_position (PgmDrawable *drawable,
   if (drawable->flags & PGM_DRAWABLE_ROTATED)
     update_transformation_matrix (drawable);
 
-  canvas = GST_OBJECT_PARENT (drawable);
-
   GST_OBJECT_UNLOCK (drawable);
 
   klass = PGM_DRAWABLE_GET_CLASS (drawable);
@@ -890,8 +887,14 @@ pgm_drawable_set_position (PgmDrawable *drawable,
     ret = klass->set_position (drawable, x, y, z);
 
   /* Reorder the drawable inside the canvas in the case that z has changed */
-  if (reordered && canvas)
-    _pgm_canvas_update_order (PGM_CANVAS (canvas), drawable);
+  if (reordered)
+    {
+      GstObject *canvas;
+
+      canvas = GST_OBJECT_PARENT (drawable);
+      if (canvas)
+        _pgm_canvas_update_order (PGM_CANVAS (canvas), drawable);
+    }
 
   if (drawable->flags & PGM_DRAWABLE_ROTATED)
     _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_TRANSFORMATION_MATRIX);
