@@ -49,15 +49,16 @@ typedef struct _PgmImage      PgmImage;
 typedef struct _PgmImageClass PgmImageClass;
 
 /* Data storage */
-typedef struct _PgmImageBuffer    PgmImageBuffer;
-typedef struct _PgmImageGstBuffer PgmImageGstBuffer;
-typedef struct _PgmImagePixbuf    PgmImagePixbuf;
-typedef union  _PgmImageData      PgmImageData;
+typedef struct _PgmImageBuffer       PgmImageBuffer;
+typedef struct _PgmImageGstBuffer    PgmImageGstBuffer;
+typedef struct _PgmImageSystemBuffer PgmImageSystemBuffer;
+typedef struct _PgmImagePixbuf       PgmImagePixbuf;
+typedef union  _PgmImageData         PgmImageData;
 
 /**
  * PgmImageAlignment:
  * @PGM_IMAGE_LEFT: Align to the left.
- * @PGM_IMAGE_CENTER: Align to the center.
+ * @PGM_IMAGE_CENTER: Align to the center (both vertically and horizontally).
  * @PGM_IMAGE_RIGHT: Align to the right.
  * @PGM_IMAGE_TOP: Align to the top.
  * @PGM_IMAGE_BOTTOM: Align to the bottom.
@@ -202,6 +203,22 @@ struct _PgmImagePixbuf {
   GdkPixbuf *pixbuf;
 };
 
+/**
+ * PgmImageSystemBuffer:
+ * @system_buffer: the system buffer pointer.
+ * @format: the system buffer format.
+ * @width: the system buffer width.
+ * @height: the system buffer height.
+ *
+ * The #PgmImageSystemBuffer structure.
+ */
+struct _PgmImageSystemBuffer {
+  gconstpointer       system_buffer;
+  PgmImagePixelFormat format;
+  guint               width;
+  guint               height;
+};
+
 /**
  * PgmImageStorageType:
  * @PGM_IMAGE_EMPTY: no image stored.
@@ -209,6 +226,7 @@ struct _PgmImagePixbuf {
  * @PGM_IMAGE_GST_BUFFER: a #PgmImageGstBuffer is stored.
  * @PGM_IMAGE_PIXBUF: a #PgmImagePixbuf is stored.
  * @PGM_IMAGE_IMAGE: a #PgmImage is stored.
+ * @PGM_IMAGE_SYSTEM_BUFFER: a #PgmImageSystemBuffer is stored.
  *
  * The different storage type.
  */
@@ -218,6 +236,7 @@ typedef enum {
   PGM_IMAGE_GST_BUFFER,
   PGM_IMAGE_PIXBUF,
   PGM_IMAGE_IMAGE,
+  PGM_IMAGE_SYSTEM_BUFFER
 } PgmImageStorageType;
 
 /**
@@ -225,13 +244,15 @@ typedef enum {
  * @buffer: the #PgmImageBuffer structure.
  * @gst_buffer: the #PgmImageGstBuffer structure.
  * @pixbuf: the #PgmImagePixbuf structure.
+ * @system_buffer: the #PgmImageSystemBuffer structure.
  *
  * The stored data depending on the storage type.
  */
 union _PgmImageData {
-  PgmImageBuffer    buffer;
-  PgmImageGstBuffer gst_buffer;
-  PgmImagePixbuf    pixbuf;
+  PgmImageBuffer       buffer;
+  PgmImageGstBuffer    gst_buffer;
+  PgmImagePixbuf       pixbuf;
+  PgmImageSystemBuffer system_buffer;
 };
 
 /**
@@ -344,6 +365,12 @@ PgmError     pgm_image_set_from_gst_buffer    (PgmImage *image,
                                                guint stride,
                                                GstBuffer *buffer);
 
+PgmError     pgm_image_set_from_system_buffer (PgmImage *image,
+                                               PgmImagePixelFormat format,
+                                               guint width,
+                                               guint height,
+                                               gconstpointer system_buffer);
+
 PgmError     pgm_image_set_from_image         (PgmImage *image,
                                                PgmImage *src_image);
 
@@ -352,9 +379,11 @@ PgmError     pgm_image_clear                  (PgmImage *image);
 PgmError     pgm_image_get_storage_type       (PgmImage *image,
                                                PgmImageStorageType *storage);
 
+PgmError     pgm_image_system_buffer_lock     (PgmImage *image);
+PgmError     pgm_image_system_buffer_unlock   (PgmImage *image);
+
 PgmError     pgm_image_set_mapping_matrix     (PgmImage *image,
                                                PgmMat4x4 *mapping_matrix);
-
 PgmError     pgm_image_get_mapping_matrix     (PgmImage *image,
                                                PgmMat4x4 **mapping_matrix);
 
@@ -407,6 +436,19 @@ PgmError     pgm_image_get_border_outer_color (PgmImage *image,
                                                guchar *blue,
                                                guchar *alpha);
 
+PgmError     pgm_image_from_drawable          (PgmImage *image,
+                                               gint *x_image,
+                                               gint *y_image,
+                                               gfloat x_drawable,
+                                               gfloat y_drawable);
+
+PgmError     pgm_image_to_drawable            (PgmImage *image,
+                                               gfloat *x_drawable,
+                                               gfloat *y_drawable,
+                                               gint x_image,
+                                               gint y_image);
+
+
 G_END_DECLS
 
 #endif /* __PGM_IMAGE_H__ */
