@@ -456,6 +456,20 @@ pgm_backend_has_alpha_component (PgmBackend *backend)
   return FALSE;
 }
 
+void
+pgm_backend_set_message_filter (PgmBackend *backend,
+                                GList *filter)
+{
+  PgmBackendClass *klass;
+
+  g_return_if_fail (PGM_IS_BACKEND (backend));
+
+  klass = PGM_BACKEND_GET_CLASS (backend);
+
+  if (klass->set_message_filter)
+    klass->set_message_filter (backend, filter);
+}
+
 gboolean
 pgm_backend_has_system_buffer (PgmBackend *backend)
 {
