@@ -744,6 +744,20 @@ do_icon (PgmContext *context,
   pgm_backend_set_icon (context->backend, icon);
 }
 
+/* Message filter update task handler */
+static void
+do_message_filter (PgmContext *context,
+                   gpointer data)
+{
+  GList *filter;
+
+  GST_OBJECT_LOCK (context->glviewport);
+  filter = PGM_VIEWPORT (context->glviewport)->message_filter;
+  GST_OBJECT_UNLOCK (context->glviewport);
+
+  pgm_backend_set_message_filter (context->backend, filter);
+}
+
 /* Drag status update task handler */
 static void
 do_drag_status (PgmContext *context,
@@ -1406,6 +1420,8 @@ init_context (PgmContext *context)
   context->task_func[PGM_CONTEXT_OPACITY] = GST_DEBUG_FUNCPTR (do_opacity);
   context->task_func[PGM_CONTEXT_CURSOR] = GST_DEBUG_FUNCPTR (do_cursor);
   context->task_func[PGM_CONTEXT_ICON] = GST_DEBUG_FUNCPTR (do_icon);
+  context->task_func[PGM_CONTEXT_MESSAGE_FILTER] =
+    GST_DEBUG_FUNCPTR (do_message_filter);
   context->task_func[PGM_CONTEXT_DRAG_STATUS] =
     GST_DEBUG_FUNCPTR (do_drag_status);
   context->task_func[PGM_CONTEXT_READ_PIXELS] =
