@@ -1075,6 +1075,21 @@ pgm_gl_viewport_get_frame_rate (PgmViewport *viewport,
   return PGM_ERROR_OK;
 }
 
+static PgmError
+pgm_gl_viewport_set_message_filter (PgmViewport *viewport,
+                                    GList *filter)
+{
+  PgmGlViewport *glviewport = PGM_GL_VIEWPORT (viewport);
+  PgmContextTask *task;
+
+  GST_LOG_OBJECT (glviewport, "set_message_filter");
+
+  task = pgm_context_task_new (PGM_CONTEXT_MESSAGE_FILTER, NULL);
+  pgm_context_push_immediate_task (glviewport->context, task);
+
+  return PGM_ERROR_OK;
+}
+
 static PgmError
 pgm_gl_viewport_read_pixels (PgmViewport *viewport,
                              guint x,
@@ -1208,6 +1223,8 @@ pgm_gl_viewport_class_init (PgmGlViewportClass *klass)
     GST_DEBUG_FUNCPTR (pgm_gl_viewport_get_caps_mask);
   viewport_class->get_frame_rate =
     GST_DEBUG_FUNCPTR (pgm_gl_viewport_get_frame_rate);
+  viewport_class->set_message_filter =
+    GST_DEBUG_FUNCPTR (pgm_gl_viewport_set_message_filter);
   viewport_class->read_pixels = GST_DEBUG_FUNCPTR (pgm_gl_viewport_read_pixels);
 
   /* PgmGlDrawable changed table */
