@@ -293,13 +293,15 @@ do_planar_12_upload (PgmTexture *texture,
   gl->bind_texture (PGM_GL_TEXTURE_2D, texture->id[1]);
   gl->tex_sub_image_2d (PGM_GL_TEXTURE_2D, 0, 0, 0, texture->cbcr_stride,
                         texture->cbcr_height, PGM_GL_LUMINANCE,
-                        PGM_GL_UNSIGNED_BYTE, ((guint8*) buffer) + texture->cb_offset);
+                        PGM_GL_UNSIGNED_BYTE,
+                        ((guint8*) buffer) + texture->cb_offset);
 
   /* Cr plane */
   gl->bind_texture (PGM_GL_TEXTURE_2D, texture->id[2]);
   gl->tex_sub_image_2d (PGM_GL_TEXTURE_2D, 0, 0, 0, texture->cbcr_stride,
                         texture->cbcr_height, PGM_GL_LUMINANCE,
-                        PGM_GL_UNSIGNED_BYTE, ((guint8*) buffer) + texture->cr_offset);
+                        PGM_GL_UNSIGNED_BYTE,
+                        ((guint8*) buffer) + texture->cr_offset);
 }
 
 /* FIXME */
@@ -314,6 +316,10 @@ static void
 do_rgb_bind (PgmTexture *texture)
 {
   gl->bind_texture (PGM_GL_TEXTURE_2D, texture->id[0]);
+
+  if (texture->storage == PGM_TEXTURE_SYSTEM_BUFFER)
+    pgm_backend_bind_system_buffer_object (context->backend,
+                                           texture->data.systembuffer);
 }
 
 /* Multi-texture and fragment program binding for the I420 to RGB color
@@ -366,6 +372,10 @@ do_uyvy_bind (PgmTexture *texture)
 static void
 do_rgb_unbind (PgmTexture *texture)
 {
+  if (texture->storage == PGM_TEXTURE_SYSTEM_BUFFER)
+    pgm_backend_release_system_buffer_object (context->backend,
+                                              texture->data.systembuffer);
+
   gl->bind_texture (PGM_GL_TEXTURE_2D, 0);
 }
 
@@ -428,6 +438,15 @@ free_buffer (PgmTexture *texture)
         texture->data.buffer = NULL;
       break;
 
+    case PGM_TEXTURE_SYSTEM_BUFFER:
+      if (texture->data.systembuffer)
+        {
+          pgm_backend_destroy_system_buffer_object (context->backend,
+                                                    texture->data.systembuffer);
+          texture->data.systembuffer = NULL;
+        }
+      break;
+
     default:
       break;
     }
@@ -578,6 +597,36 @@ pgm_texture_set_buffer (PgmTexture *texture,
   update_normalized_size (texture);
 }
 
+void
+pgm_texture_set_system_buffer (PgmTexture *texture,
+                               gconstpointer system_buffer,
+                               PgmImagePixelFormat csp,
+                               guint width,
+                               guint height)
+{
+  free_buffer (texture);
+
+  texture->storage = PGM_TEXTURE_SYSTEM_BUFFER;
+  texture->data.systembuffer =
+    pgm_backend_create_system_buffer_object (context->backend, system_buffer,
+                                             csp);
+  texture->width = width;
+  texture->height = height;
+  texture->csp = csp;
+  texture->norm_width = 1.0f;
+  texture->norm_height = 1.0f;
+  texture->inv_norm_width = 1.0f;
+  texture->inv_norm_height = 1.0f;
+
+  /* FIXME: The power-of-two size is biased here since in the GLX backend we
+   *        use the non-power-of-two extension. If that's not done here, the
+   *        GlImage object generates wrong texture coordinates. That has to
+   *        be fixed adding good support for non-power-of-two texture in the
+   *        plugin. */
+  texture->width_pot = width;
+  texture->height_pot = height;
+}
+
 void
 pgm_texture_set_pixbuf (PgmTexture *texture,
                         GdkPixbuf *pixbuf)
