@@ -71,7 +71,11 @@ struct _PgmWglBackend {
   const gchar *extensions;
 
   /* Message source id */
-  guint message_id;
+  guint   message_id;
+
+  /* Message events filter */
+  GArray *message_filter;
+  guint   message_filter_len;
 
   /* WGL features */
   guint feature_mask;
