@@ -368,20 +368,21 @@ PGM_START_TEST (test_image_gst_buffer)
 }
 PGM_END_TEST
 
-#define IMAGE_FROM_DRAWABLE_TEST(x_drawable, y_drawable, x_image, y_image) \
-  do { \
-    ASSERT_PGM_SUCCESS (pgm_image_from_drawable (image, &x, &y, \
-                                                 x_drawable, y_drawable)); \
-    fail_unless_equals_int (x, x_image); \
-    fail_unless_equals_int (y, y_image); \
-  }while(0)
+/* Fight against rounding issues using a threshold comparison of 1 */
+#define IMAGE_FROM_DRAWABLE_TEST(x_drb,y_drb,x_img,y_img)               \
+  G_STMT_START {                                                        \
+    ASSERT_PGM_SUCCESS (pgm_image_from_drawable (image, &x, &y,         \
+                                                 x_drb, y_drb));        \
+    fail_unless (abs (x-x_img) <= 1);                                   \
+    fail_unless (abs (y-y_img) <= 1);                                   \
+  } G_STMT_END
 
 #define IMAGE_FROM_DRAWABLE_3_TESTS(x1,y1,x2,y2,x3,y3) \
-    do { \
-      IMAGE_FROM_DRAWABLE_TEST (0.0f, 0.0f, x1, y1); \
-      IMAGE_FROM_DRAWABLE_TEST (2.0f, 1.0f, x2, y2); \
-      IMAGE_FROM_DRAWABLE_TEST (-1.0f, -1.0f, x3, y3); \
-    }while(0)
+  G_STMT_START {                                       \
+    IMAGE_FROM_DRAWABLE_TEST (0.0f, 0.0f, x1, y1);     \
+    IMAGE_FROM_DRAWABLE_TEST (2.0f, 1.0f, x2, y2);     \
+    IMAGE_FROM_DRAWABLE_TEST (-1.0f, -1.0f, x3, y3);   \
+  } G_STMT_END
 
 PGM_START_TEST (test_image_from_drawable)
 {
@@ -469,9 +470,7 @@ PGM_START_TEST (test_image_from_drawable)
   ASSERT_PGM_SUCCESS (pgm_image_set_layout (image, PGM_IMAGE_SCALED));
   ASSERT_PGM_SUCCESS (pgm_image_set_alignment (image, PGM_IMAGE_RIGHT));
 
-  /* that 3rd param should be 1024 and not 1023, but there's some rounding error
-   * happening, not sure this can be fixed without using doubles */
-  IMAGE_FROM_DRAWABLE_3_TESTS (-341, 0, 1023, 1024, -1024, -1024);
+  IMAGE_FROM_DRAWABLE_3_TESTS (-341, 0, 1024, 1024, -1024, -1024);
 
   ASSERT_PGM_SUCCESS (pgm_image_set_aspect_ratio (image, old_n, old_d));
 
